==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRecordDescriptionMetadata } from "./WebGroupByRecordDescriptionMetadata";
import { WebGroupByRowSelectorTemplateDetailsDescription } from "./WebGroupByRowSelectorTemplateDetailsDescription";
/**
 * @hidden
 */
export let WebGroupByRowSelectorTemplateDetailsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupByRowSelectorTemplateDetailsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a == null) {
                WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.c(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a);
            }
            if (a.k(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a);
            WebGroupByRecordDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupByRowSelectorTemplateDetails");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
            a.item("SelectedCount", "Number:double");
            a.item("TotalCount", "Number:double");
            a.item("GroupRow", "ExportedType:WebGroupByRecord");
        }
        static d(a) {
            WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.b(a);
            a.ad("WebGroupByRowSelectorTemplateDetails", () => new WebGroupByRowSelectorTemplateDetailsDescription());
            a.ac("WebGroupByRowSelectorTemplateDetails", WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a);
        }
    }
    WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.$t = markType(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata, 'WebGroupByRowSelectorTemplateDetailsDescriptionMetadata');
    WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a = null;
    return WebGroupByRowSelectorTemplateDetailsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRecordDescriptionMetadata } from "./WebGroupByRecordDescriptionMetadata";
import { WebGroupByRowSelectorTemplateDetailsDescription } from "./WebGroupByRowSelectorTemplateDetailsDescription";
/**
 * @hidden
 */
export let WebGroupByRowSelectorTemplateDetailsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupByRowSelectorTemplateDetailsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a == null) {
                WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.c(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a);
            }
            if (a.k(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a);
            WebGroupByRecordDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupByRowSelectorTemplateDetails");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
            a.item("SelectedCount", "Number:double");
            a.item("TotalCount", "Number:double");
            a.item("GroupRow", "ExportedType:WebGroupByRecord");
        }
        static d(a) {
            WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.b(a);
            a.ae("WebGroupByRowSelectorTemplateDetails", () => new WebGroupByRowSelectorTemplateDetailsDescription());
            a.ad("WebGroupByRowSelectorTemplateDetails", WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a);
        }
    }
    WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.$t = markType(WebGroupByRowSelectorTemplateDetailsDescriptionMetadata, 'WebGroupByRowSelectorTemplateDetailsDescriptionMetadata');
    WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.a = null;
    return WebGroupByRowSelectorTemplateDetailsDescriptionMetadata;
})();
